/*
 * Name:    d_monop.h
 *
 * Purpose: Private declarations of monochromator dependency type handlers.
 *
 * This file is intended to be included only by the file 'libmx/d_mono.c'
 * and should not be include by any other file.
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __D_MONOP_H__
#define __D_MONOP_H__

static mx_status_type mxd_monochromator_get_pointers( MX_MOTOR *motor,
					MX_MONOCHROMATOR **monochromator,
					const char *calling_fname );

static mx_status_type mxd_monochromator_get_enable_status(
					MX_RECORD *list_record, 
					int *dependency_type );

static mx_status_type mxd_monochromator_get_dependency_type(
					MX_RECORD *list_record, 
					int *dependency_type );

static mx_status_type mxd_monochromator_get_param_array_from_list(
					MX_RECORD *list_record,
					int *num_parameters,
					double **parameter_array );

static mx_status_type mxd_monochromator_get_record_array_from_list(
					MX_RECORD *list_record,
					int *num_records,
					MX_RECORD ***record_array );

static mx_status_type mxd_monochromator_any_limit_hit(
					MX_MOTOR *motor,
					int direction );

/* === */

static mx_status_type mxd_monochromator_get_theta_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *theta_position );
static mx_status_type mxd_monochromator_set_theta_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position );
static mx_status_type mxd_monochromator_move_theta(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_energy_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *theta_position );
static mx_status_type mxd_monochromator_set_energy_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position );
static mx_status_type mxd_monochromator_move_energy(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_polynomial_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *theta_position );
static mx_status_type mxd_monochromator_set_polynomial_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position );
static mx_status_type mxd_monochromator_move_polynomial(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_insertion_device_energy_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *id_energy_position );
static mx_status_type mxd_monochromator_set_insertion_device_energy_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double id_energy_position );
static mx_status_type mxd_monochromator_move_insertion_device_energy(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_bragg_normal_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *bragg_normal_position );
static mx_status_type mxd_monochromator_set_bragg_normal_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double bragg_normal_position );
static mx_status_type mxd_monochromator_move_bragg_normal(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_bragg_translation_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *bragg_translation_position );
static mx_status_type mxd_monochromator_set_bragg_translation_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double bragg_translation_position );
static mx_status_type mxd_monochromator_move_bragg_translation(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_table_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *table_position );
static mx_status_type mxd_monochromator_set_table_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double table_position );
static mx_status_type mxd_monochromator_move_table(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

static mx_status_type mxd_monochromator_get_diffractometer_theta_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double *theta_position );
static mx_status_type mxd_monochromator_set_diffractometer_theta_position(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position );
static mx_status_type mxd_monochromator_move_diffractometer_theta(
					MX_MONOCHROMATOR *monochromator,
					MX_RECORD *list_record, 
					double theta_position,
					double old_theta_position,
					int flags );

#endif /* __D_MONOP_H__ */
