/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:    d_pmac.h
 *
 * Purpose: Header file for MX drivers for Delta Tau PMAC controlled motors.
 */

#ifndef __D_PMAC_H__
#define __D_PMAC_H__

#include "i_pmac.h"

/* ============ Motor channels ============ */

typedef struct {
	MX_INTERFACE pmac_interface;
	int motor_number;
} MX_PMAC_MOTOR;

MX_API mx_status_type mxd_pmac_initialize_type( long type );
MX_API mx_status_type mxd_pmac_create_record_structures( MX_RECORD *record );
MX_API mx_status_type mxd_pmac_finish_record_initialization(MX_RECORD *record);
MX_API mx_status_type mxd_pmac_delete_record( MX_RECORD *record );
MX_API mx_status_type mxd_pmac_print_structure( FILE *file,
						MX_RECORD *record );
MX_API mx_status_type mxd_pmac_read_parms_from_hardware(
						MX_RECORD *record );
MX_API mx_status_type mxd_pmac_write_parms_to_hardware(
						MX_RECORD *record );
MX_API mx_status_type mxd_pmac_open( MX_RECORD *record );
MX_API mx_status_type mxd_pmac_close( MX_RECORD *record );


MX_API mx_status_type mxd_pmac_motor_is_busy( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_move_absolute( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_get_position( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_set_position( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_soft_abort( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_immediate_abort( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_positive_limit_hit( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_negative_limit_hit( MX_MOTOR *motor );
MX_API mx_status_type mxd_pmac_find_home_position( MX_MOTOR *motor );

extern MX_RECORD_FUNCTION_LIST mxd_pmac_record_function_list;
extern MX_MOTOR_FUNCTION_LIST mxd_pmac_motor_function_list;

extern long mxd_pmac_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_pmac_rfield_def_ptr;

#define MXD_PMAC_STANDARD_FIELDS \
  {-1, -1, "pmac_interface", MXFT_INTERFACE, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_PMAC_MOTOR, pmac_interface), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "motor_number", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_PMAC_MOTOR, motor_number), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

#endif /* __D_PMAC_H__ */
