/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:    mx_ain.h
 *
 * Purpose: MX header file for analog input devices.
 */

#ifndef __MX_AIN_H__
#define __MX_AIN_H__

#include "mx_rec.h"

#define MX_ANALOG_INPUT_FUZZ	(1.0e-9)

typedef struct {
	MX_RECORD *record; /* Pointer to the MX_RECORD structure that points
                            * to this device.
                            */
	int subclass;

	long raw_value;
	double value;
	double scale;
	double offset;
	char units[MXU_UNITS_NAME_LENGTH+1];
} MX_ANALOG_INPUT;

#define MXLV_AIN_VALUE	2001

#define MX_ANALOG_INPUT_STANDARD_FIELDS \
  {-1, -1, "subclass", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_ANALOG_INPUT, subclass), \
	{0}, NULL, 0}, \
  \
  {-1, -1, "raw_value", MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_ANALOG_INPUT, raw_value), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {MXLV_AIN_VALUE, -1, "value", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_ANALOG_INPUT, value), \
	{0}, NULL, MXFF_IN_SUMMARY}, \
  \
  {-1, -1, "scale", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_ANALOG_INPUT, scale), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "offset", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_ANALOG_INPUT, offset), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "units", MXFT_STRING, NULL, 1, {MXU_UNITS_NAME_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_ANALOG_INPUT, units), \
	{sizeof(char)}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

/*
 * The structure type MX_ANALOG_INPUT_FUNCTION_LIST contains a list of
 * pointers to functions that vary from analog input type to analog
 * input type.
 */

typedef struct {
	mx_status_type ( *read ) ( MX_ANALOG_INPUT *adc );
} MX_ANALOG_INPUT_FUNCTION_LIST;

MX_API mx_status_type mx_analog_input_read( MX_RECORD *adc_record,
							double *value );

MX_API mx_status_type mx_analog_input_read_raw( MX_RECORD *adc_record,
							long *raw_value );

extern MX_RECORD_FUNCTION_LIST mx_analog_input_record_function_list;

#endif /* __MX_AIN_H__ */
