/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:    mx_amp.h
 *
 * Purpose: MX header file for amplifier support.
 */

#ifndef __MX_AMP_H__
#define __MX_AMP_H__

#include "mx_rec.h"

typedef struct {
	MX_RECORD *record; /* Pointer to the MX_RECORD structure that points
			    * to this amplifier.
			    */
	double gain;
	double offset;
	double time_constant;
} MX_AMPLIFIER;

#define MXLV_AMP_GAIN		8001
#define MXLV_AMP_OFFSET		8002
#define MXLV_AMP_TIME_CONSTANT	8003

#define MX_AMPLIFIER_STANDARD_FIELDS \
  {MXLV_AMP_GAIN, -1, "gain", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_AMPLIFIER, gain), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_AMP_OFFSET, -1, "offset", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_AMPLIFIER, offset), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_AMP_TIME_CONSTANT, -1, "time_constant", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_AMPLIFIER, time_constant), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

typedef struct {
	mx_status_type ( *get_gain ) ( MX_AMPLIFIER *amplifier );
	mx_status_type ( *set_gain ) ( MX_AMPLIFIER *amplifier );
	mx_status_type ( *get_offset ) ( MX_AMPLIFIER *amplifier );
	mx_status_type ( *set_offset ) ( MX_AMPLIFIER *amplifier );
	mx_status_type ( *get_time_constant ) ( MX_AMPLIFIER *amplifier );
	mx_status_type ( *set_time_constant ) ( MX_AMPLIFIER *amplifier );
} MX_AMPLIFIER_FUNCTION_LIST;

MX_API mx_status_type mx_amplifier_get_gain( MX_RECORD *amplifier_record,
							double *gain );

MX_API mx_status_type mx_amplifier_set_gain( MX_RECORD *amplifier_record,
							double gain );

MX_API mx_status_type mx_amplifier_get_offset( MX_RECORD *amplifier_record,
							double *offset );

MX_API mx_status_type mx_amplifier_set_offset( MX_RECORD *amplifier_record,
							double offset );

MX_API mx_status_type mx_amplifier_get_time_constant(
			MX_RECORD *amplifier_record, double *time_constant );

MX_API mx_status_type mx_amplifier_set_time_constant(
			MX_RECORD *amplifier_record, double time_constant );

#endif /* __MX_AMP_H__ */
