/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/* mmca.c - MCA control functions. */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "motor.h"
#include "mx_mca.h"
#include "mx_key.h"

int
motor_mca_fn( int argc, char *argv[] )
{
	MX_RECORD *mca_record;
	MX_MCA *mca;
	double counting_time;
	int i, busy;
	unsigned long *channel_array;
	mx_status_type mx_status;

	static char usage[]
		= "Usage:  mca count 'counting_time' 'mca_name'\n";

	if ( argc != 5 ) {
		fprintf( output, "%s\n", usage );
		return FAILURE;
	}


	if ( strncmp( "count", argv[2], strlen(argv[2]) ) == 0 ) {

		counting_time = atof( argv[3] );

		mca_record = mx_get_record( motor_record_list, argv[4] );

		if ( mca_record == NULL ) {
			fprintf( output, "The record '%s' does not exist.",
				argv[4] );
			return FAILURE;
		}

		mca = (MX_MCA *) mca_record->record_class_struct;

		if ( mca == (MX_MCA *) NULL ) {
			fprintf( output,
				"MX_MCA pointer for record '%s' is NULL.\n",
				mca_record->name );
			return FAILURE;
		}

		mx_status = mx_mca_start_for_preset_time(
				mca_record, counting_time );

		if ( mx_status.code != MXE_SUCCESS )
			return FAILURE;

		busy = TRUE;

		while( busy ) {
			mx_status = mx_mca_is_busy( mca_record, &busy );

			if ( mx_status.code != MXE_SUCCESS )
				return FAILURE;

			mx_msleep(500);
		}

		/* Read out the acquired data. */

		fprintf( output, "About to read MCA data.\n" );

		mx_status = mx_mca_read( mca_record, &channel_array );

		if ( mx_status.code != MXE_SUCCESS )
			return FAILURE;

		/* Display the data. */

		fprintf( output, "MCA data successfully read.\n" );
		fprintf( output, "\n" );

#if 1
		fprintf( output, "Hit any key to continue...\n" );
		mx_getch();
#endif

		for ( i = 0; i < mca->current_num_channels; i++ ) {
			fprintf( output, "%lu ", channel_array[i] );

#if 1
			if ( ((i+1) % 1000) == 0 ) {
				fprintf( output,
				"\nHit any key to continue...\n" );
				mx_getch();
			}
#endif
		}

		fprintf( output, "\n" );
	} else {
		/* Unrecognized command. */

		fprintf( output, "Unrecognized option '%s'\n\n", argv[2] );
		fprintf( output, "%s\n", usage );
		return FAILURE;
	}
	return SUCCESS;
}

